.trx_addons_ai_helper_button{align-items:center;display:flex;flex-direction:row;justify-content:center;width:100%}[class*=trx_addons_ai_helper_button_icon]{font-size:15px;line-height:20px}[class*=trx_addons_ai_helper_button_icon]:before{font-size:15px;margin-right:6px}[class*=trx_addons_ai_helper_button_icon].dashicons-update:before{animation:trx-addons-animation-spin 2s linear infinite;display:inline-block}@keyframes trx-addons-animation-spin{0%{transform:rotate(0deg)}to{transform:rotate(1turn)}}.trx_addons_ai_helper_response__variant{display:block;margin:0 0 1em}.trx_addons_ai_helper_response__variant:last-child{margin-bottom:0}.trx_addons_ai_helper_response__content{max-height:15em;min-width:33vw}
